@@ -1,3 +1,3 @@
 from .verification import verify_response, verify_signed_in, verify_config_variables, verify_rest_api_version, \
-    verify_api_method_exists
+    verify_api_method_exists, verify_connection
 from .validation import validate_schedule_state_override
